@@ -36,52 +36,34 @@ our $VERSION = '0.01';
 1;
 __END__
 # Below is stub documentation for your module. You'd better edit it!
-
 =head1 NAME
-
-DuckCurses - Perl extension for blah blah blah
+  
+DuckCurses - Duck Tales game using curses library
 
 =head1 SYNOPSIS
 
   use DuckCurses;
-  blah blah blah
+
+  init DuckCursesMain.pm to play it.
 
 =head1 DESCRIPTION
 
-Stub documentation for DuckCurses, created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
+Dagobert Duck jumping around on his (pogo)stick killing baddies :-)
 
 =head2 EXPORT
 
-None by default.
-
-
-
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
-
 =head1 AUTHOR
 
-shameen, E<lt>shameen@lanE<gt>
+Kobold Wizard Johan, E<lt>koboldwiz@yahoo.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2021 by shameen
+Copyright (C) 2021 by Kobold Wizard Johan
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.32.0 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
