@@ -3,8 +3,8 @@ package DuckCurses::dagobert;
 use parent 'DuckCurses::entity';
 
 sub new {
-        my ($class, $name) = @_;
-        my $self = $class->SUPER::new;
+        my ($class, $x, $y) = @_;
+        my $self = $class->SUPER::new ($x,$y, 'd');
 
 }
 
